@@ -1,5 +1,6 @@
 import os
 import json
+from unittest.mock import ANY
 
 import pytest
 
@@ -48,24 +49,29 @@ def test_parse(context, mocker):
     result = context.http.get(url)
     data = result.serialize()
 
-    with mocker.patch.object(context, "emit"):
-        rules = {'pattern': 'https://httpbin.org/*'}
-        context.params["store"] = rules
-        parse(context, data)
-        assert context.emit.call_count == 1
-        context.emit.assert_called_once_with(rule="fetch", data={
-            "url": "https://www.iana.org/domains/example"
-        })
+    mocker.patch.object(context, "emit")
+
+    rules = {'pattern': 'https://httpbin.org/*'}
+    context.params["store"] = rules
+    context.params["meta"] = {
+        "title": ".//h1",
+        "description": ".//p"
+    }
+    parse(context, data)
+    assert context.emit.call_count == 1
+    context.emit.assert_called_once_with(rule="fetch", data=ANY)
 
     # cleanup tags
     conn = connect_redis()
     conn.flushall()
 
-    with mocker.patch.object(context, "emit"):
-        context.http.result = None
-        context.params["store"] = None
-        parse(context, data)
-        assert context.emit.call_count == 2, data
+    context.http.result = None
+    context.params["store"] = None
+    parse(context, data)
+    assert data['url'] == 'https://www.iana.org/domains/example'
+    assert data['title'] == 'Example Domain'
+    assert data['description'].startswith('This domain is for')
+    assert context.emit.call_count == 3, data
 
 
 def test_seed(context, mocker):
@@ -82,19 +88,19 @@ def test_seed(context, mocker):
 
 
 def test_sequence(context, mocker):
-    with mocker.patch.object(context, "emit"):
-        context.params["start"] = 2
-        context.params["stop"] = 11
-        context.params["step"] = 3
-        sequence(context, data={})
-        assert context.emit.call_count == 3
+    mocker.patch.object(context, "emit")
 
-    with mocker.patch.object(context, "emit"):
-        context.params["start"] = 7
-        context.params["stop"] = 1
-        context.params["step"] = -3
-        sequence(context, data={})
-        assert context.emit.call_count == 2
+    context.params["start"] = 2
+    context.params["stop"] = 11
+    context.params["step"] = 3
+    sequence(context, data={})
+    assert context.emit.call_count == 3
+
+    context.params["start"] = 7
+    context.params["stop"] = 1
+    context.params["step"] = -3
+    sequence(context, data={})
+    assert context.emit.call_count == 5
 
 
 def test_dates(context, mocker):
